==> softcorp_flutter_core-1.0.33.tar.gz: lib/default_multi_select/default_multi_select.dart <==
import 'package:flutter/material.dart';
import 'package:multi_select_flutter/chip_display/multi_select_chip_display.dart';
import 'package:multi_select_flutter/dialog/multi_select_dialog_field.dart';
import 'package:multi_select_flutter/util/multi_select_item.dart';
import 'package:multi_select_flutter/util/multi_select_list_type.dart';
import '../constants.dart';

class DefaultMultiSelect extends StatelessWidget {
  final Map<String, dynamic> items;
  final List<dynamic>? initialValues;
  final void Function(List<dynamic>) onConfirm;
  final String title;
  final double? width;

  const DefaultMultiSelect({Key? key, required this.items, required this.title, required this.onConfirm, this.initialValues, this.width}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.all(7.5),
      width: width,
      child: MultiSelectDialogField(
        items: items.entries.map((item) {
          return MultiSelectItem(item.value, item.key);
        }).toList(),
        listType: MultiSelectListType.LIST,
        backgroundColor: Colors.white,
        initialValue: initialValues,
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(defaultCornerRadius),
          border: Border.all(width: 1, color: Colors.black12),
        ),
        buttonText: Text(
          title,
          style: const TextStyle(color: defaultBodyColor),
        ),
        chipDisplay: MultiSelectChipDisplay(
          chipColor: defaultPrimaryColor,
          textStyle: const TextStyle(color: Colors.white),
        ),
        confirmText: const Text(
          "Select",
          style: TextStyle(color: Colors.black),
        ),
        cancelText: const Text(
          "Cancel",
          style: TextStyle(color: Colors.black),
        ),
        height: 500,
        onConfirm: onConfirm,
        title: Text(
          title,
          style: const TextStyle(color: defaultTitleColor),
        ),
        buttonIcon: const Icon(
          Icons.arrow_drop_down_rounded,
          color: defaultTitleColor,
        ),
      ),
    );
  }
}

==> softcorp_flutter_core-1.0.55.tar.gz: lib/default_multi_select/default_multi_select.dart <==
import 'package:flutter/material.dart';
import 'package:multi_select_flutter/chip_display/multi_select_chip_display.dart';
import 'package:multi_select_flutter/dialog/multi_select_dialog_field.dart';
import 'package:multi_select_flutter/util/multi_select_item.dart';
import 'package:multi_select_flutter/util/multi_select_list_type.dart';
import '../constants.dart';

class DefaultMultiSelect extends StatelessWidget {
  final Map<String, dynamic> items;
  final List<dynamic>? initialValues;
  final void Function(List<dynamic>) onConfirm;
  final String title;
  final double? width;
  final Color? chipColor;

  const DefaultMultiSelect({Key? key, required this.items, required this.title, required this.onConfirm, this.initialValues, this.width, this.chipColor}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.all(7.5),
      width: width,
      child: MultiSelectDialogField(
        items: items.entries.map((item) {
          return MultiSelectItem(item.value, item.key);
        }).toList(),
        listType: MultiSelectListType.LIST,
        backgroundColor: Colors.white,
        initialValue: initialValues,
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(defaultCornerRadius),
          border: Border.all(width: 1, color: Colors.black12),
        ),
        buttonText: Text(
          title,
          style: const TextStyle(color: defaultBodyColor),
        ),
        chipDisplay: MultiSelectChipDisplay(
          chipColor: chipColor ?? defaultPrimaryColor,
          textStyle: const TextStyle(color: Colors.white),
        ),
        confirmText: const Text(
          "Select",
          style: TextStyle(color: Colors.black),
        ),
        cancelText: const Text(
          "Cancel",
          style: TextStyle(color: Colors.black),
        ),
        height: 500,
        onConfirm: onConfirm,
        title: Text(
          title,
          style: const TextStyle(color: defaultTitleColor),
        ),
        buttonIcon: const Icon(
          Icons.arrow_drop_down_rounded,
          color: defaultTitleColor,
        ),
      ),
    );
  }
}
